Merged revisions 76718 via svnmerge from
svn+ssh://pythondev@svn.python.org/python/trunk

........
  r76718 | antoine.pitrou | 2009-12-08 20:35:12 +0100 (mar., 08 déc. 2009) | 3 lines

  Fix transient refleaks in test_urllib. Thanks to Florent Xicluna.
........
diff --git a/Lib/urllib/parse.py b/Lib/urllib/parse.py
index a27b975..16f46d6 100644
--- a/Lib/urllib/parse.py
+++ b/Lib/urllib/parse.py
@@ -41,8 +41,9 @@
 _parse_cache = {}
 
 def clear_cache():
     """Clear the parse cache."""
     _parse_cache.clear()
+    _safe_quoters.clear()
 
 
 class ResultMixin(object):
@@ -41,8 +41,9 @@
 
 def clear_cache():
-    """Clear the parse cache."""
+    """Clear the parse cache and the quoters cache."""
     _parse_cache.clear()